@@ -1,6 +1,6 @@
 package Catalyst::Model::REST;
 BEGIN {
-  $Catalyst::Model::REST::VERSION = '0.14';
+  $Catalyst::Model::REST::VERSION = '0.15';
 }
 use 5.010;
 use Moose;
@@ -58,6 +58,9 @@ sub _call {
 		headers => { 'content-type' => $self->_serializer->content_type },
 		content => $self->_serializer->serialize($data)
 	}) : $self->_ua->request($method, $uri);
+	# Return an error if status 5XX
+	return { code =>  $res->{status}, error => $res->{reason}} if $res->{status} > 499;
+
 	# Try to find a serializer for the result content
 	my $content_type = $res->{headers}{content_type};
 	my $deserializer = $self->_serializer($content_type);
@@ -107,7 +110,7 @@ Catalyst::Model::REST - REST model class for Catalyst
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
